parse_bedlike_file

Function parse_bedlike_file 

pub fn parse_bedlike_file(line: &str) -> Option<(String, i32, i32)>
Parses each line of given bed like file into a contig (chromosome), starts and ends This ignores any other columns beyond start and ends.