RegionSet

Struct RegionSet 

pub struct RegionSet {
    pub regions: Vec<Region>,
    pub header: Option<String>,
    pub path: Option<PathBuf>,
}
RegionSet struct, the representation of the interval region set file, such as bed file.

Fields

regions: Vec<Region>header: Option<String>path: Option<PathBuf>

Implementations

Source

impl RegionSet

pub fn to_bed<T: AsRef<Path>>(&self, path: T) -> Result<()>

Save a regionset to disk as bed file

Arguments
  • path: the path to the file to dump to
pub fn to_bed_gz<T: AsRef<Path>>(&self, path: T) -> Result<()>

Save a regionset to disk as bed.gz file

Arguments
  • path: the path to the file to dump to
pub fn identifier(&self) -> String

Calculate identifier for RegionSet

This function doesn’t sort file, and identifer is based on unsorted first 3 columns.

Returns

String containing RegionSet identifier

pub fn file_digest(&self) -> String

pub fn iter_chroms(&self) -> impl Iterator<Item = &String>

Iterate unique chromosomes located in RegionSet

pub fn iter_chr_regions<'a>( &'a self, chr: &'a str, ) -> impl Iterator<Item = &'a Region>

Iterate through regions located on specific Chromosome in RegionSet

Arguments
  • chr: chromosome name
pub fn sort(&mut self)

Sort bed file based on first 3 columns. Sorting is happening inside the object, where original order will be overwritten

pub fn is_empty(&self) -> bool

Is regionSet empty?

pub fn region_widths(&self) -> Result<Vec<u32>>

Calculate all regions width

pub fn mean_region_width(&self) -> f64

Calculate mean region width for whole RegionSet

pub fn calc_mid_points(&self) -> HashMap<String, Vec<u32>>

Calculate middle point for each region, and return hashmap with midpoints for each chromosome

pub fn len(&self) -> usize

Get number of regions in RegionSet

Returns: number of regions

pub fn get_max_end_per_chr(&self) -> HashMap<String, u32>

Get the furthest region location for each region

pub fn nucleotides_length(&self) -> u32

Get total nucleotide count